import type { RouteRecordRaw } from 'vue-router'

const asyncRouter: RouteRecordRaw[] = [
  {
    path: '/home',
    name: 'home',
    component: () => import('@/views/exception/403.vue'),
    meta: {
      title: '首页',
      icon: 'House'
    }
  },
  {
    path: 'https://jijian.sxidc.com/',
    name: 'jijian',
    component: () => ({}),
    meta: {
      title: '极简低代码',
      icon: 'Aim'
    }
  },
  {
    path: '/system',
    name: 'system',
    meta: {
      title: '系统管理',
      icon: 'icon-system'
    },
    children: [
      {
        path: '/system/user',
        name: 'systemUser',
        component: () => import('@/views/system/User.vue'),
        meta: {
          title: '用户管理',
          icon: 'user'
        }
      },
      {
        path: '/system/role',
        name: 'systemRole',
        component: () => import('@/views/system/Role.vue'),
        meta: {
          title: '角色管理',
          icon: 'avatar'
        }
      },
      {
        path: '/system/dict',
        name: 'systemDict',
        component: () => import('@/views/system/Dict.vue'),
        meta: {
          title: '字典管理',
          icon: 'memo'
        }
      },
      {
        path: '/system/menu',
        name: 'systemMenu',
        component: () => import('@/views/system/Menu.vue'),
        meta: {
          title: '菜单管理',
          icon: 'menu'
        }
      }
    ]
  },
  {
    path: '/org',
    name: 'org',
    meta: {
      title: '组织机构',
      icon: 'OfficeBuilding'
    },
    children: [
      {
        path: '/org/orgList',
        name: 'orgList',
        component: () => import('@/views/org/Org.vue'),
        meta: {
          title: '机构管理',
          icon: 'OfficeBuilding'
        }
      }
    ]
  },
  {
    path: '/miniprogram',
    name: 'miniprogram',
    meta: {
      title: '小程序管理',
      icon: 'icon-system'
    },
    children: [
      {
        path: '/miniprogram/banner',
        name: 'miniBanner',
        component: () => import('@/views/miniprogram/Banner.vue'),
        meta: {
          title: '轮播图',
          icon: 'picture'
        }
      },
      {
        path: '/miniprogram/question',
        name: 'miniQuestion',
        component: () => import('@/views/miniprogram/Question.vue'),
        meta: {
          title: '常见问题',
          icon: 'QuestionFilled'
        }
      },
      {
        path: '/miniprogram/feedback',
        name: 'miniFeedback',
        component: () => import('@/views/miniprogram/Feedback.vue'),
        meta: {
          title: '意见反馈',
          icon: 'Promotion'
        }
      },
      {
        path: '/miniprogram/about',
        name: 'miniAbout',
        component: () => import('@/views/miniprogram/About.vue'),
        meta: {
          title: '关于我们',
          icon: 'user'
        }
      },
      {
        path: '/miniprogram/version',
        name: 'miniVersion',
        component: () => import('@/views/miniprogram/Version.vue'),
        meta: {
          title: '版本信息',
          icon: 'list'
        }
      }
    ]
  },
  {
    path: '/list',
    name: 'list',
    meta: {
      title: '列表页',
      icon: 'icon-list-view'
    },
    children: [
      {
        path: '/list/cardList',
        name: 'cardList',
        component: () => import('@/views/list/CardList.vue'),
        meta: {
          title: '卡片列表',
          icon: 'icon-bank-card'
        }
      }
    ]
  },
  {
    path: '/form',
    name: 'form',
    meta: {
      title: '表单页',
      icon: 'Notebook'
    },
    children: [
      {
        path: '/form/basic',
        name: 'formBasic',
        component: () => import('@/views/form/Basic.vue'),
        meta: {
          title: '基础表单'
        }
      },
      {
        path: '/form/advanced',
        name: 'formAdvanced',
        component: () => import('@/views/form/Advanced.vue'),
        meta: {
          title: '高级表单'
        }
      }
    ]
  },
  {
    path: '/result',
    name: 'result',
    meta: {
      title: '结果页',
      icon: 'CircleCheck'
    },
    children: [
      {
        path: '/result/success',
        name: 'resultSuccess',
        component: () => import('@/views/result/Success.vue'),
        meta: {
          title: '成功页'
        }
      },
      {
        path: '/result/error',
        name: 'resultError',
        component: () => import('@/views/result/Error.vue'),
        meta: {
          title: '失败页'
        }
      }
    ]
  },
  {
    path: '/monitor',
    name: 'monitor',
    meta: {
      title: '系统监控',
      icon: 'Notification'
    },
    children: [
      {
        path: '/monitor/logList',
        name: 'logList',
        component: () => import('@/views/monitor/LogList.vue'),
        meta: {
          title: '日志查询',
          icon: 'List'
        }
      },
      {
        path: '/monitor/messageNotif',
        name: 'logList',
        component: () => import('@/views/monitor/MessageNotif.vue'),
        meta: {
          title: '消息通知',
          icon: 'ChatRound'
        }
      }
    ]
  },
  {
    path: '/userInfo',
    name: 'userInfo',
    component: () => import('@/views/user/UserInfo.vue'),
    meta: {
      title: '个人中心',
      icon: 'House'
    },
    hidden: true
  },
  {
    path: '/:pathMatch(.*)*',
    redirect: '/exception/404',
    hidden: true
  }
]

export default asyncRouter
